@@ -177,15 +177,7 @@ PROMPT is the prompt shown to the user."
   (completing-read-multiple prompt (citre--ctags-language-list)))
 
 (defun citre--encode-path-to-filename (path)
-  "Encode local absolute PATH into a file name.
-If PATH is a directory, the caller may want to ensure there's an
-ending slash, as:
-
-- A directory is also a file.
-- Its filename is its directory name without the final slash.
-- So the filename and directory name are encoded to different results.
-
-See also `directory-file-name'."
+  "Encode local absolute PATH into a file name."
   (let ((segs (split-string
                ;; expand the "~" so Unix paths will start with a slash. This
                ;; also collapses consecutive slashes.
@@ -238,7 +230,7 @@ This also works on remote machine."
 DIR is absolute.  The full path of the tags file is returned."
   (expand-file-name
    (concat (citre--encode-path-to-filename
-            (file-name-as-directory (file-local-name (file-truename dir))))
+            (file-local-name (file-truename dir)))
            ".tags")
    (citre--tags-global-cache-dir)))
 
@@ -599,7 +591,15 @@ When SYNC is non-nil, update the tags file synchronously."
 ;;;###autoload
 (defun citre-edit-tags-file-recipe (&optional tagsfile)
   "Edit the recipe of TAGSFILE.
-When called interactively, ask the user to select a tags file."
+When called interactively, ask the user to select a tags file.
+
+When CMD-PTAG is non-nil, don't use a command-editing buffer, but
+write it to CITRE_CMD ptag directly.
+
+When CWD is non-nil, don't ask the user to pick a root dir to run Ctags.
+
+When NOCONFIRM is non-nil, don't ask the user whether to update
+the tags file now (update it directly instead)."
   (interactive)
   (let ((tagsfile (or tagsfile (citre-read-tags-file-name))))
     (citre--ctags-edit-recipe tagsfile)))
